@@ -405,7 +405,9 @@ class Intents(BaseFlags):
     @classmethod
     def from_list(cls, intents_list):
         """A factory method that creates a :class:`Intents` with everything enabled
-        that has been passed in the list."""
+        that has been passed in the list.
+
+        .. versionadded:: 1.5.0.1"""
         for item in intents_list:
             if item not in cls.VALID_FLAGS.keys():
                 intents_list.remove(item)
@@ -609,7 +611,7 @@ class Intents(BaseFlags):
         """
         return 1 << 8
 
-    @flag_value
+    @alias_flag_value
     def messages(self):
         """:class:`bool`: Whether guild and direct message related events are enabled.
 
@@ -692,7 +694,7 @@ class Intents(BaseFlags):
         """
         return 1 << 12
 
-    @flag_value
+    @alias_flag_value
     def reactions(self):
         """:class:`bool`: Whether guild and direct message reaction related events are enabled.
 
@@ -755,7 +757,7 @@ class Intents(BaseFlags):
         """
         return 1 << 13
 
-    @flag_value
+    @alias_flag_value
     def typing(self):
         """:class:`bool`: Whether guild and direct message typing related events are enabled.
 
